
#line 3 "<stdout>"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define yy_create_buffer bx_create_buffer
#define yy_delete_buffer bx_delete_buffer
#define yy_flex_debug bx_flex_debug
#define yy_init_buffer bx_init_buffer
#define yy_flush_buffer bx_flush_buffer
#define yy_load_buffer_state bx_load_buffer_state
#define yy_switch_to_buffer bx_switch_to_buffer
#define yyin bxin
#define yyleng bxleng
#define yylex bxlex
#define yylineno bxlineno
#define yyout bxout
#define yyrestart bxrestart
#define yytext bxtext
#define yywrap bxwrap
#define yyalloc bxalloc
#define yyrealloc bxrealloc
#define yyfree bxfree

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 35
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;
#endif /* ! C99 */

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE bxrestart(bxin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 16384
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

extern int bxleng;

extern FILE *bxin, *bxout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up bxtext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up bxtext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via bxrestart()), so that the user can continue scanning by
	 * just pointing bxin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when bxtext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int bxleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow bxwrap()'s to do buffer switches
 * instead of setting up a fresh bxin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void bxrestart (FILE *input_file  );
void bx_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE bx_create_buffer (FILE *file,int size  );
void bx_delete_buffer (YY_BUFFER_STATE b  );
void bx_flush_buffer (YY_BUFFER_STATE b  );
void bxpush_buffer_state (YY_BUFFER_STATE new_buffer  );
void bxpop_buffer_state (void );

static void bxensure_buffer_stack (void );
static void bx_load_buffer_state (void );
static void bx_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER bx_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE bx_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE bx_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE bx_scan_bytes (yyconst char *bytes,int len  );

void *bxalloc (yy_size_t  );
void *bxrealloc (void *,yy_size_t  );
void bxfree (void *  );

#define yy_new_buffer bx_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        bxensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            bx_create_buffer(bxin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        bxensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            bx_create_buffer(bxin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

typedef unsigned char YY_CHAR;

FILE *bxin = (FILE *) 0, *bxout = (FILE *) 0;

typedef int yy_state_type;

extern int bxlineno;

int bxlineno = 1;

extern char *bxtext;
#define yytext_ptr bxtext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up bxtext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	bxleng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 203
#define YY_END_OF_BUFFER 204
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[444] =
    {   0,
        0,    0,    0,    0,    0,    0,  204,  201,    1,  199,
      186,  201,  200,  201,  183,  201,  188,  189,  179,  177,
      178,  180,  194,  194,  198,  201,  201,  172,  187,  197,
      185,  195,   18,    6,   43,  195,  195,  195,  171,  195,
      195,  195,  195,   12,  195,   13,   48,   26,   10,  195,
       59,  195,   80,   49,  184,  202,    1,  202,  198,  202,
        1,    0,  191,    0,  200,  196,    0,  190,    0,  195,
      193,  194,    0,  182,  181,  197,  195,  109,   93,  113,
      110,   94,  119,  195,  114,  195,  111,   95,  195,  195,
       21,  164,  115,  195,  112,  118,   96,  195,  195,   23,

      167,  116,  195,  195,  195,  195,  195,  195,  165,  195,
      195,   29,  168,  195,  195,  169,  195,  195,  195,  161,
      195,  195,   16,  195,  195,  195,  195,  195,  195,    3,
      195,   18,  195,  195,  195,  195,  195,  195,  195,  197,
      153,  154,  195,  195,  195,  195,  195,  195,  195,   71,
      195,  195,  117,  195,  120,  195,  166,  195,  195,  195,
      195,  195,  195,  195,   15,  195,  195,  195,  195,  195,
       50,  174,  175,  176,  196,  192,   92,  195,   45,   44,
      100,  195,  195,  195,   33,    5,  195,   42,   98,  195,
       56,  195,  195,  129,  135,  130,  131,  134,  132,  195,

      162,  133,  136,  195,  195,   29,   36,  195,  195,   61,
       34,  195,  195,   57,   35,  195,  195,   37,  195,   32,
      195,  197,  195,    4,  195,  195,   91,  195,   58,  195,
      195,  195,  195,  195,  155,  156,  157,  158,  159,  160,
      101,  137,  121,  102,  138,  122,  145,  152,  146,  147,
      150,  148,  195,  195,   27,  195,  163,  149,  151,   72,
        2,  195,   97,  195,  195,   99,  195,   30,  195,  195,
      195,  195,   39,  195,  195,   38,  195,  195,   90,  195,
      195,  195,   31,  195,  195,  173,    7,   22,  195,  195,
       64,   24,  195,   47,  195,  195,  171,   20,  195,  195,

      195,  195,  195,  197,   88,   11,   89,  195,  195,  195,
      195,  195,  195,   46,  103,  139,  123,  104,  140,  124,
      105,  141,  125,  106,  142,  126,  107,  143,  127,  108,
      144,  128,   79,  195,  195,   27,  195,  195,   81,   69,
      195,   25,    9,   63,  195,  195,   55,  195,  195,  195,
      195,  195,  195,   14,   17,  195,  195,  195,  195,  170,
      195,  195,  195,   82,   40,  195,  197,  195,  195,  195,
      195,   70,   53,  195,  195,  195,  195,   84,  195,  195,
       65,  195,  195,   77,   86,   80,  195,   41,   60,   85,
      195,   16,   75,   19,  195,  195,  195,   73,  195,  195,

      195,  195,  195,  195,  195,   15,  195,  195,   54,  195,
      195,  195,   51,   52,  195,   83,  195,  195,   78,    8,
      195,   74,  195,  195,  195,  195,  195,  195,  195,  195,
       28,  195,   67,   66,   62,  195,  195,  195,   76,  195,
       68,   87,    0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    4,    5,    6,    7,    1,    8,    9,   10,
       11,   12,   13,    1,   14,    1,   15,   16,   17,   18,
       19,   20,   21,   22,   22,   23,   24,    1,   25,   26,
        1,   27,   28,   29,   30,   30,   30,   30,   30,   30,
       31,   31,   31,   31,   31,   31,   31,   31,   31,   31,
       31,   31,   31,   31,   31,   31,   31,   31,   31,   31,
        1,   32,    1,   33,   31,    1,   34,   35,   36,   37,

       38,   39,   40,   41,   42,   43,   44,   45,   46,   47,
       48,   49,   50,   51,   52,   53,   54,   55,   56,   57,
       58,   59,    1,   60,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[61] =
    {   0,
        1,    1,    2,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    3,    1,    4,    4,    4,    4,    4,
        4,    4,    4,    4,    1,    1,    1,    1,    1,    5,
        6,    1,    1,    7,    8,    8,    8,    7,    7,    9,
        9,    9,   10,   10,   10,    9,   10,    9,   10,   10,
       10,    9,    9,    9,   10,    9,   11,   10,   10,    1
    } ;

static yyconst flex_int16_t yy_base[458] =
    {   0,
        0,    0,   59,   61,   63,   65,  218, 2459,  210, 2459,
     2459,   64,    0,    0, 2459,   61, 2459, 2459, 2459, 2459,
        0, 2459,   48,    0, 2459,  185,  179, 2459, 2459,    0,
     2459,   92,  136,   83,  156,  180,   40,  127,  185,  198,
      199,  217,  214,   92,  234,  256,  261,  302,  325,  301,
      114,  349,  346,  229, 2459, 2459,  201,  389, 2459,    0,
      198,   68, 2459,    0,    0,    0,   66, 2459,    0,    0,
       79,    0,    0, 2459, 2459,    0,  387,  406,  407,  420,
      421,  434,  443,  448,  457,  462,  471,  476,  296,  487,
      507,  324,  500,  512,  519,  526,  539,  540,  553,  562,

      567,  576,  581,  590,  595,  608,  613,  622,  627,  640,
      649,  654,  668,  669,  682,  683,  696,  697,  710,  715,
      724,  735,  738,  749,  756,  763,  772,  781,  790,  795,
      808,  809,  822,  825,  841,  848,  863,  864,  879,  311,
       64,   90,  882,  891,  896,  909,  923,  920,  937,   43,
      381,  248,  947,  955,  259,  962,  975,  982,  983,  992,
      652,  868,  997, 1005, 1012, 1019, 1020, 1040, 1041, 1048,
     1051,    0,    0,    0,    0,    0, 1061, 1062, 1070, 1071,
     1081, 1084, 1091, 1092, 1101, 1106, 1114, 1121, 1128, 1129,
     1136, 1143, 1150, 1151, 1158, 1165, 1172, 1173, 1180, 1187,

     1194, 1195, 1202, 1209, 1216, 1217, 1224, 1231, 1238, 1239,
     1246, 1259, 1260, 1268, 1269, 1288, 1283, 1291, 1296, 1311,
     1318,  126, 1319, 1326, 1339, 1346, 1347, 1356, 1361, 1366,
     1369, 1383, 1386, 1391,  136,  153,  154,  364,  494,  564,
        0,    0,    0,    0,    0,    0, 1394, 1405, 1413, 1414,
     1422, 1427, 1435, 1442, 1449, 1452, 1459, 1462, 1472, 1473,
     1481, 1482, 1492, 1501, 1506, 1509, 1514, 1523, 1528, 1533,
     1536, 1556, 1547, 1564, 1561, 1569, 1578, 1586, 1583, 1591,
     1600, 1605, 1608, 1613, 1627, 1628, 1636, 1641, 1649, 1656,
     1663, 1664, 1671, 1678, 1685, 1686, 1693, 1700, 1707, 1708,

     1715, 1728, 1735,  183,    0, 1738, 1743, 1748, 1757, 1767,
     1758, 1778, 1781, 1786,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0, 1789, 1800, 1808, 1809, 1819, 1822, 1829, 1830,
     1839, 1844, 1849, 1854, 1859, 1864, 1869, 1879, 1874, 1884,
     1889, 1899, 1904, 1909, 1912, 1919, 1929, 1934, 1939, 1942,
     1953, 1956, 1963, 1966, 1977, 1985,  180, 1980, 1999, 2002,
     2009, 2016, 2019, 2026, 2033, 2036, 2041, 2055, 2056, 2064,
     2085, 2077, 2078, 2092, 2099, 2100, 2107, 2114, 2122, 2129,
     2136, 2137, 2144, 2151, 2158, 2159,  143, 2166, 2179, 2186,

     2187, 2194, 2201,   36, 2208, 2211, 2216, 2221, 2230, 2231,
      133, 2238, 2245, 2252,  137, 2259,  144,  142, 2260, 2267,
     2274, 2282,   70, 2289,  127,  128,  122, 2296,  112,  103,
     2299,  107,    0,    0, 2304,   94,   79,   81,    0,   78,
        0,    0, 2459, 2356, 2367, 2378, 2385, 2396, 2405, 2413,
      103, 2421, 2430,   90, 2438, 2446, 2447
    } ;

static yyconst flex_int16_t yy_def[458] =
    {   0,
      443,    1,  444,  444,  444,  444,  443,  443,  443,  443,
      443,  445,  446,  447,  443,  448,  443,  443,  443,  443,
      449,  443,  450,  451,  443,  443,  443,  443,  443,  452,
      443,  453,  453,   33,   33,   33,   33,   33,   33,   33,
       33,   40,   40,   40,   40,   33,   33,   36,   33,   33,
       40,   40,   33,   33,  443,  443,  443,  443,  443,  454,
      443,  445,  443,  445,  446,  455,  448,  443,  448,  449,
      450,  451,  456,  443,  443,  452,   33,   33,   33,   33,
       33,   33,   33,   33,   33,   33,   33,   33,   40,   40,
       40,   40,   40,   33,   33,   33,   33,   33,   33,   33,

       33,   33,   33,   33,   33,   33,   33,   33,   33,   33,
       33,   33,   33,   33,   33,   33,   33,   33,   33,   33,
       33,   33,   33,   33,   40,   33,   40,   33,   33,   33,
       33,   33,   33,   40,   40,   40,   40,   40,   40,  452,
      452,  452,   33,   33,   33,   33,   33,   33,   33,  147,
      147,  147,  147,  147,  147,  147,  147,  147,  147,  147,
      147,  147,  147,  147,  147,  147,  147,  147,  147,  147,
      147,   58,  457,  454,  455,  456,  147,  147,  147,  147,
      147,  147,  147,  147,  147,  147,  147,  147,  147,  147,
      147,  147,  147,  147,  147,  147,  147,  147,  147,  147,

      147,  147,  147,  147,  147,  147,  147,  147,  147,  147,
      147,  147,  147,  147,  147,  147,  147,  147,  147,  147,
      147,  452,  147,  147,  147,  147,  147,  147,  147,  147,
      147,  147,  147,  147,  452,  452,  452,  452,  452,  452,
      452,  452,  452,  452,  452,  452,  147,  147,  147,  147,
      147,  147,  147,  147,  147,  147,  147,  147,  147,  147,
      147,  147,  147,  147,  147,  147,  147,  147,  147,  147,
      147,  147,  147,  147,  147,  147,  147,  147,  147,  147,
      147,  147,  147,  147,  147,  147,  147,  147,  147,  147,
      147,  147,  147,  147,  147,  147,  147,  147,  147,  147,

      147,  147,  147,  452,  452,  147,  147,  147,  147,  147,
      147,  147,  147,  147,  452,  452,  452,  452,  452,  452,
      452,  452,  452,  452,  452,  452,  452,  452,  452,  452,
      452,  452,  147,  147,  147,  147,  147,  147,  147,  147,
      147,  147,  147,  147,  147,  147,  147,  147,  147,  147,
      147,  147,  147,  147,  147,  147,  147,  147,  147,  147,
      147,  147,  147,  147,  147,  147,  452,  147,  147,  147,
      147,  147,  147,  147,  147,  147,  147,  147,  147,  147,
      147,  147,  147,  147,  147,  147,  147,  147,  147,  147,
      147,  147,  147,  147,  147,  147,  449,  147,  147,  147,

      147,  147,  147,  449,  147,  147,  147,  147,  147,  147,
      449,  147,  147,  147,  449,  147,  449,  449,  147,  147,
      147,  147,  449,  147,  449,  449,  449,  147,  449,  449,
      147,  449,  449,  449,  147,  449,  449,  449,  449,  449,
      449,  449,    0,  443,  443,  443,  443,  443,  443,  443,
      443,  443,  443,  443,  443,  443,  443
    } ;

static yyconst flex_int16_t yy_nxt[2520] =
    {   0,
        8,    9,   10,   11,   12,   13,   14,   15,   16,   17,
       18,   19,   20,   21,   22,   23,   24,   24,   24,   24,
       24,   24,   24,   24,   25,   26,   27,   28,   29,   30,
       30,    8,   31,   32,   33,   34,   35,   36,   37,   38,
       39,   40,   41,   41,   42,   43,   44,   45,   46,   47,
       48,   49,   50,   51,   52,   53,   54,   41,   41,   55,
       57,   10,   57,   10,   57,   10,   57,   10,   63,   68,
       72,   72,   63,   58,   68,   58,  260,   60,   77,   60,
       77,  417,   77,   59,  111,   59,  418,   59,  112,   59,
       77,  113,   69,  174,   77,   64,   77,   69,  241,   64,

      242,   72,   72,  429,   73,   70,   72,   76,   76,   76,
       76,   76,   76,   76,   76,   76,   86,  442,  441,  243,
      430,   76,   76,   87,  244,  440,  245,   88,   77,  128,
       89,   90,   78,   91,   92,  443,   79,  439,   77,   93,
       77,  304,   77,  438,  437,  246,   77,  436,   80,   70,
       77,   76,   76,   76,   76,   76,   76,   76,   76,   76,
      164,  434,   77,  114,   77,   76,   76,   77,   77,  305,
      315,  115,  316,  433,  432,   77,   81,   77,  116,  427,
       82,  426,  425,   77,   83,  423,   84,  318,  321,  319,
      322,  317,   85,   94,  411,  305,   95,   96,  367,   61,

       97,   98,   61,   99,   77,   75,  100,  101,  320,  323,
       74,   61,  102,  103,  104,  105,  106,  443,  107,  443,
       77,  108,  117,  443,   77,   77,  443,  443,   77,   77,
       77,  109,  443,   77,  118,   77,  110,  443,   77,   77,
      443,   77,   77,   77,  119,  443,  120,   77,  121,   77,
       77,  123,  122,  124,   77,   77,  443,  443,  125,  126,
       77,  127,   77,   77,   77,   77,  443,   77,   77,   77,
       77,   77,  129,   77,  170,  443,  443,  171,  443,   77,
      130,   77,   77,   77,   77,   77,  443,   77,   77,  131,
      132,  133,   77,  134,   77,  262,   77,  135,   77,   77,

      136,   77,  443,  266,   77,   77,  137,  443,  138,   77,
       77,   77,   77,  443,  139,  443,  443,   77,  140,  443,
      443,  443,  443,  443,  141,  142,  235,  236,  237,  238,
      239,  240,   77,  443,  161,  143,  144,  145,  146,  147,
       77,   77,  184,  148,   77,   77,   77,  443,  443,   77,
       77,  162,  163,  149,  443,  443,  443,   77,   77,  150,
       77,  443,  151,  443,  443,  152,  153,  443,  443,  154,
       77,  443,   77,  155,   77,  156,  157,  158,   77,  167,
      159,   77,  160,  165,  443,   77,  168,  443,  166,  443,
       77,  443,  443,  443,   77,   77,  169,   77,  324,   77,

      325,  443,   77,   77,  172,  172,  172,  172,  172,  172,
      172,  172,  172,  443,   77,  443,   77,  443,  443,  326,
       77,  443,  443,  173,  173,  173,  443,   77,  173,  173,
      173,   77,   77,  261,  173,   77,  173,   77,  443,  443,
      173,  173,  173,   77,  173,  173,   77,   77,  443,  443,
       77,  177,  443,  443,   77,   77,   77,   77,  443,  443,
       77,   77,   77,   77,   77,   77,  443,  443,   77,   77,
       77,   77,  443,  443,   77,  178,   77,   77,   77,  179,
      180,  443,   77,   77,   77,  182,  443,  181,   77,  443,
       77,   77,   77,   77,  443,  443,   77,   77,   77,   77,

      443,   77,   77,  443,   77,   77,  183,   77,  443,  443,
       77,   77,   77,   77,  443,   77,   77,  443,   77,   77,
       77,   77,  443,   77,   77,  443,   77,   77,  327,  443,
      328,  443,   77,   77,  443,   77,   77,   77,  443,  443,
      185,   77,  186,   77,  187,  443,   77,  443,   77,  329,
       77,  443,   77,   77,   77,   77,  188,   77,  443,   77,
       77,   77,   77,   77,  443,  443,   77,   77,   77,   77,
      189,  443,  443,  191,   77,   77,   77,  190,  443,   77,
       77,  443,   77,   77,   77,  443,  443,   77,   77,   77,
       77,  443,  443,   77,  192,   77,   77,   77,  330,  193,

      331,   77,   77,   77,  443,  443,   77,   77,  443,   77,
       77,   77,   77,  443,  443,   77,   77,   77,   77,  332,
       77,   77,  443,   77,   77,   77,   77,  443,  443,   77,
       77,   77,   77,  443,   77,   77,  443,  194,  195,   77,
       77,  443,  443,   77,  443,   77,  196,  443,   77,  198,
      443,  197,   77,   77,  443,  443,   77,  200,   77,  443,
      443,   77,   77,   77,  199,  443,   77,   77,  202,   77,
      201,   77,   77,  443,  443,  203,  443,   77,   77,  443,
       77,  204,  205,   77,   77,   77,  273,   77,   77,   77,
       77,   77,  443,   77,   77,  274,   77,   77,   77,   77,

      443,  443,   77,   77,   77,   77,  443,  206,   77,   77,
       77,  443,   77,   77,  443,  443,   77,   77,   77,   77,
      443,  207,   77,   77,   77,   77,   77,   77,  443,  208,
       77,   77,   77,   77,  443,  443,   77,   77,   77,   77,
      209,   77,  443,  443,   77,   77,   77,   77,  212,  211,
       77,  443,  210,   77,   77,   77,  443,  443,   77,   77,
       77,  213,  443,   77,   77,   77,   77,  443,   77,  443,
      443,   77,   77,  214,   77,   77,  443,  443,   77,   77,
       77,  443,   77,   77,  443,   77,   77,  215,  216,   77,
      443,   77,   77,   77,   77,  443,  443,   77,  222,   77,

      217,  218,  219,   77,   77,   77,   77,   77,  221,  443,
       77,   77,  443,   77,  443,  443,  443,  443,   77,  220,
       77,   77,   77,  443,  443,   77,   77,  443,  224,   77,
       77,   77,  443,  443,   77,   77,  443,  223,   77,   77,
       77,  443,  443,   77,  443,   77,   77,  225,   77,   77,
      443,   77,   77,   77,  443,  443,   77,   77,   77,  226,
      443,   77,   77,  227,   77,   77,   77,  443,  443,  443,
       77,  228,   77,   77,  443,   77,  229,   77,   77,   77,
      443,  230,  443,  443,   77,  443,  443,   77,  443,   77,
      443,   77,  443,  443,   77,   77,   77,  443,   77,   77,

       77,  275,   77,   77,  231,  232,  443,   77,  443,   77,
       77,   77,   77,   77,   77,   77,  233,   77,   77,   77,
      234,  443,   77,  443,  443,   77,   77,   77,  443,   77,
       77,   77,   77,   77,  443,   77,   77,  443,  247,  248,
       77,   77,  443,  443,   77,  443,   77,  249,  443,   77,
      251,  443,  250,   77,  443,  443,  253,   77,  254,   77,
       77,  443,  255,   77,   77,  252,  443,   77,  257,  443,
       77,   77,  443,   77,  256,  443,   77,   77,  258,   77,
       77,   77,   77,  443,  443,  259,   77,   77,   77,  443,
       77,  263,  443,   77,   77,   77,  265,   77,   77,  267,

      443,   77,  443,  443,  443,  264,   77,  443,   77,  443,
       77,  443,  268,   77,   77,   77,   77,   77,   77,  269,
      443,   77,   77,  443,  271,   77,   77,   77,  443,  270,
       77,   77,   77,   77,   77,  443,   77,  272,   77,  443,
       77,  443,  443,   77,   77,   77,  443,   77,  276,  443,
      443,   77,  279,   77,   77,   77,   77,  443,   77,   77,
      277,  443,  278,   77,  443,  443,  443,  443,  443,  443,
       77,   77,  280,   77,   77,   77,   77,  281,  443,   77,
       77,   77,  282,   77,   77,  443,   77,   77,  443,  443,
       77,   77,   77,  283,   77,   77,   77,   77,  443,   77,

       77,   77,   77,   77,   77,   77,   77,  443,  443,   77,
       77,  443,   77,  284,   77,  443,   77,  285,  443,   77,
       77,   77,   77,   77,   77,   77,  286,   77,  443,  443,
       77,   77,   77,  443,   77,   77,   77,  443,  443,   77,
       77,   77,   77,   77,  287,   77,  443,   77,  443,   77,
      443,  443,   77,  288,   77,  443,   77,   77,  289,  443,
       77,   77,  290,   77,   77,   77,  443,   77,   77,   77,
      443,   77,   77,  443,  443,   77,   77,  443,   77,   77,
       77,  443,   77,   77,   77,   77,   77,   77,  443,  292,
       77,   77,  443,   77,   77,  291,  443,   77,   77,  443,

       77,   77,   77,  443,   77,   77,   77,   77,   77,   77,
      443,   77,   77,   77,  443,   77,   77,  443,  443,   77,
      293,  443,   77,   77,   77,  443,   77,   77,   77,   77,
       77,   77,  443,   77,   77,   77,  443,   77,   77,  443,
      443,   77,   77,  443,   77,   77,   77,  443,   77,   77,
       77,   77,   77,   77,  443,  295,   77,   77,  443,   77,
       77,  294,  443,   77,   77,  296,   77,   77,   77,  443,
       77,   77,   77,   77,   77,   77,  443,   77,   77,   77,
      443,   77,   77,  443,  443,   77,  297,  443,  443,   77,
       77,  443,   77,   77,   77,   77,  443,   77,   77,   77,

      443,   77,   77,   77,   77,  443,  298,   77,   77,  443,
       77,   77,  299,  443,  443,  443,   77,  443,   77,   77,
       77,   77,   77,   77,   77,  300,   77,   77,  443,   77,
       77,   77,  443,  443,   77,   77,  443,  443,  443,   77,
      301,  443,   77,  443,   77,  443,   77,   77,  443,  302,
       77,   77,   77,   77,   77,  303,  443,   77,   77,   77,
      443,   77,   77,  443,  443,   77,  443,  443,  443,   77,
       77,  306,   77,  443,   77,  443,  307,   77,   77,   77,
       77,   77,   77,  308,  443,   77,   77,  443,  443,   77,
       77,   77,  309,  443,   77,   77,   77,   77,   77,   77,

       77,   77,   77,  443,   77,   77,  443,   77,   77,  443,
      443,  443,   77,  443,  443,  311,   77,   77,   77,   77,
       77,   77,   77,  310,   77,   77,   77,   77,  312,   77,
       77,  443,  443,   77,   77,  443,  313,   77,   77,  443,
       77,  443,   77,  314,   77,   77,   77,   77,   77,   77,
      443,  443,   77,   77,  443,   77,   77,   77,  443,  443,
       77,   77,   77,  443,   77,   77,   77,  443,   77,  443,
       77,  333,  443,   77,   77,   77,  443,   77,   77,  443,
      443,   77,   77,  443,   77,   77,   77,   77,   77,  334,
      335,   77,   77,   77,   77,   77,  443,   77,   77,  443,

      336,   77,  443,   77,  337,   77,   77,   77,   77,  443,
       77,   77,   77,   77,   77,   77,   77,   77,  443,  443,
       77,   77,  443,   77,   77,   77,  443,   77,  443,  338,
      443,   77,   77,   77,   77,  443,   77,  339,  340,   77,
       77,   77,   77,   77,   77,   77,  443,   77,   77,   77,
      443,  443,   77,  342,  443,  443,   77,  341,   77,  443,
       77,   77,   77,   77,  443,   77,   77,   77,   77,   77,
      443,   77,   77,  443,   77,   77,  343,  443,  443,   77,
       77,  344,   77,  443,   77,  443,   77,   77,  345,   77,
      346,   77,  443,  443,   77,   77,  348,   77,   77,   77,

       77,  347,   77,   77,   77,  443,  443,   77,   77,  443,
      443,  349,   77,   77,  443,   77,   77,   77,   77,   77,
       77,   77,   77,  350,   77,   77,  351,  443,  443,   77,
       77,  443,  443,   77,   77,   77,  443,   77,   77,   77,
       77,   77,   77,   77,   77,  443,   77,   77,   77,  443,
      352,   77,   77,  443,  443,  443,   77,  353,  443,   77,
       77,   77,   77,   77,   77,  354,   77,   77,  443,   77,
      355,   77,  443,  443,   77,   77,   77,  356,   77,   77,
       77,  443,   77,  443,   77,  443,  443,   77,   77,   77,
      443,   77,   77,  443,  443,   77,   77,   77,   77,   77,

       77,  357,   77,   77,   77,  443,   77,  358,  443,  443,
      359,   77,  443,   77,   77,   77,  443,   77,   77,  361,
       77,   77,   77,  443,   77,   77,   77,  443,   77,   77,
      443,  443,   77,   77,  443,   77,  360,   77,  443,   77,
       77,  363,   77,   77,   77,  443,   77,   77,   77,  443,
       77,   77,  443,  443,   77,  443,  443,  362,   77,   77,
      364,   77,  443,   77,  443,  443,   77,   77,   77,  366,
       77,   77,  443,   77,   77,  443,   77,   77,   77,   77,
      443,  368,   77,   77,  365,  443,   77,   77,  443,   77,
       77,   77,   77,   77,   77,  443,   77,   77,  369,   77,

       77,  370,   77,  443,  443,  443,   77,  443,   77,   77,
      371,   77,  443,   77,   77,  372,   77,   77,   77,   77,
       77,   77,   77,  443,   77,   77,  443,  443,   77,   77,
      443,  443,   77,   77,  443,   77,  443,   77,  373,   77,
       77,   77,   77,   77,   77,  443,  443,   77,   77,  443,
      374,   77,   77,  443,   77,   77,  443,   77,   77,  375,
       77,   77,   77,   77,   77,   77,  376,  377,   77,   77,
       77,  443,   77,   77,   77,  443,  443,   77,   77,   77,
       77,   77,   77,   77,   77,  443,  443,   77,   77,   77,
       77,  378,   77,   77,  379,   77,  443,   77,   77,   77,

       77,  443,   77,   77,   77,   77,  443,   77,   77,   77,
       77,  380,   77,   77,   77,   77,  381,  383,   77,   77,
       77,  443,   77,   77,   77,   77,  382,  443,   77,  384,
       77,  443,   77,  443,   77,   77,  385,   77,   77,   77,
       77,  386,   77,   77,   77,   77,  443,   77,   77,  443,
       77,   77,   77,  443,   77,   77,  443,  443,   77,  443,
       77,  443,   77,   77,   77,  387,  388,   77,   77,   77,
       77,  443,   77,   77,   77,   77,  443,   77,   77,  389,
       77,   77,  443,  443,  443,   77,   77,  443,   77,   77,
      360,   77,   77,   77,  443,   77,   77,  390,   77,   77,

      443,   77,   77,  443,   77,   77,  392,   77,  443,  391,
       77,  443,   77,   77,   77,   77,   77,   77,   77,   77,
       77,  443,  397,  394,   77,  443,  443,  443,   77,  443,
      443,   77,   77,  393,   77,  396,   77,   77,   77,  443,
      443,   77,   77,  443,   77,  395,  443,  443,   77,   77,
       77,   77,   77,   77,   77,   77,  443,  443,   77,   77,
       77,   77,  398,  443,  443,   77,   77,   77,   77,   77,
       77,   77,   77,  443,   77,   77,   77,   77,  401,  443,
       77,  443,  443,  443,   77,  399,  400,   77,   77,   77,
       77,   77,   77,  443,   77,   77,  402,   77,  404,   77,

      443,  443,  443,   77,  443,  443,   77,   77,  403,  443,
       77,   77,  405,   77,  443,   77,   77,   77,   77,  443,
       77,  406,  443,  443,   77,   77,  443,   77,   77,   77,
      443,   77,   77,   77,   77,   77,   77,  443,   77,   77,
       77,  443,   77,   77,  443,  443,   77,   77,  443,   77,
       77,   77,  443,   77,  443,   77,  443,   77,   77,  443,
      407,   77,   77,  443,   77,   77,  443,  443,   77,   77,
       77,   77,   77,   77,  443,   77,   77,   77,  443,   77,
       77,  408,  443,   77,   77,  443,   77,   77,   77,  443,
       77,   77,   77,   77,  410,   77,  443,  409,   77,   77,

      443,   77,   77,  443,  443,   77,  443,  415,  443,   77,
       77,  443,   77,  443,   77,  443,  412,   77,   77,   77,
       77,   77,   77,  413,  443,   77,   77,   77,  443,   77,
       77,  443,  414,   77,   77,  443,   77,   77,   77,  443,
       77,   77,  443,   77,   77,   77,   77,   77,  419,   77,
       77,   77,  416,  420,   77,   77,   77,  443,  421,   77,
       77,  443,   77,   77,   77,   77,   77,   77,  443,   77,
       77,   77,   77,   77,  422,  443,  443,   77,   77,  443,
       77,   77,   77,  443,   77,   77,  443,   77,  424,   77,
      443,   77,   77,   77,   77,   77,   77,  443,   77,   77,

       77,  443,   77,   77,  443,  443,   77,   77,  443,   77,
       77,   77,  443,   77,  443,   77,  443,   77,   77,  443,
      428,   77,   77,  443,   77,   77,  443,  443,   77,   77,
      443,   77,   77,   77,   77,   77,  443,   77,   77,   77,
      431,  443,  443,   77,  443,  443,  443,   77,  435,  443,
       77,  443,  443,  443,  443,   77,   56,   56,   56,   56,
       56,   56,   56,   56,   56,   56,   56,   62,  443,   62,
       62,   62,   62,   62,   62,   62,   62,   62,   65,  443,
       65,   65,   65,   65,   65,   65,   65,   65,   65,   66,
       66,   66,   66,   66,   66,   66,   67,  443,   67,   67,

       67,   67,   67,   67,   67,   67,   67,   70,  443,  443,
      443,   70,   70,   70,   70,   70,   71,  443,  443,  443,
      443,  443,  443,   71,   76,   76,   76,   76,   76,   76,
       76,   76,   77,   77,   77,   77,   77,   77,   77,   77,
       77,  175,  175,  175,  175,  175,  175,  175,  175,  176,
      176,  443,  176,  176,  173,  173,  443,  173,    7,  443,
      443,  443,  443,  443,  443,  443,  443,  443,  443,  443,
      443,  443,  443,  443,  443,  443,  443,  443,  443,  443,
      443,  443,  443,  443,  443,  443,  443,  443,  443,  443,
      443,  443,  443,  443,  443,  443,  443,  443,  443,  443,

      443,  443,  443,  443,  443,  443,  443,  443,  443,  443,
      443,  443,  443,  443,  443,  443,  443,  443,  443
    } ;

static yyconst flex_int16_t yy_chk[2520] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        3,    3,    4,    4,    5,    5,    6,    6,   12,   16,
       23,   23,   62,    3,   67,    4,  150,    5,  150,    6,
       37,  404,  150,    3,   37,    4,  404,    5,   37,    6,
       37,   37,   16,  454,  150,   12,   37,   67,  141,   62,

      141,   71,   71,  423,   23,   32,  451,   32,   32,   32,
       32,   32,   32,   32,   32,   32,   34,  440,  438,  141,
      423,   32,   32,   34,  142,  437,  142,   34,   44,   44,
       34,   34,   32,   34,   34,   71,   32,  436,   44,   34,
       44,  222,   44,  432,  430,  142,   44,  429,   32,   33,
       51,   33,   33,   33,   33,   33,   33,   33,   33,   33,
       51,  427,   51,   38,   51,   33,   33,   38,   51,  222,
      235,   38,  235,  426,  425,   38,   33,   38,   38,  418,
       33,  417,  415,   38,   33,  411,   33,  236,  237,  236,
      237,  235,   33,   35,  397,  367,   35,   35,  304,   61,

       35,   35,   57,   35,   35,   27,   35,   35,  236,  237,
       26,    9,   35,   36,   36,   36,   36,    7,   36,    0,
       36,   36,   39,    0,   36,   39,    0,    0,   36,   39,
       36,   36,    0,   39,   40,   39,   36,    0,   40,   41,
        0,   39,   40,   41,   40,    0,   40,   41,   40,   41,
       43,   42,   40,   42,   40,   41,    0,    0,   42,   43,
       43,   43,   43,   42,   43,   42,    0,   42,   43,   54,
       45,   42,   45,   54,   54,    0,    0,   54,    0,   54,
       45,  152,   45,  152,   45,   54,    0,  152,   45,   46,
       46,   46,  155,   46,  155,  152,   46,   46,  155,  152,

       46,   47,    0,  155,   46,   47,   46,    0,   46,   47,
      155,   47,   46,    0,   47,    0,    0,   47,   48,    0,
        0,    0,    0,    0,   48,   48,  140,  140,  140,  140,
      140,  140,   89,    0,   50,   48,   48,   48,   48,   48,
       48,   50,   89,   48,   89,   50,   89,    0,    0,   50,
       89,   50,   50,   48,    0,    0,    0,   50,   48,   49,
       92,    0,   49,    0,    0,   49,   49,    0,    0,   49,
       92,    0,   92,   49,   92,   49,   49,   49,   92,   53,
       49,   49,   49,   52,    0,   52,   53,    0,   52,    0,
       53,    0,    0,    0,   53,   52,   53,   52,  238,   52,

      238,    0,   53,   52,   58,   58,   58,   58,   58,   58,
       58,   58,   58,    0,  151,    0,  151,    0,    0,  238,
      151,    0,    0,   58,   58,   58,    0,   77,   58,   58,
       58,   77,  151,  151,   58,   77,   58,   77,    0,    0,
       58,   58,   58,   77,   58,   58,   78,   79,    0,    0,
       78,   79,    0,    0,   78,   79,   78,   79,    0,    0,
       80,   81,   78,   79,   80,   81,    0,    0,   80,   81,
       80,   81,    0,    0,   82,   82,   80,   81,   82,   83,
       83,    0,   82,   83,   82,   84,    0,   83,   84,    0,
       82,   83,   84,   83,    0,    0,   84,   85,   84,   83,

        0,   85,   86,    0,   84,   85,   86,   85,    0,    0,
       86,   87,   86,   85,    0,   87,   88,    0,   86,   87,
       88,   87,    0,   90,   88,    0,   88,   87,  239,    0,
      239,    0,   88,   90,    0,   90,   93,   90,    0,    0,
       90,   90,   91,   91,   91,    0,   93,    0,   93,  239,
       93,    0,   94,   91,   93,   91,   94,   91,    0,   95,
       94,   91,   94,   95,    0,    0,   96,   95,   94,   95,
       96,    0,    0,   98,   96,   95,   96,   96,    0,   97,
       98,    0,   96,   97,   98,    0,    0,   97,   98,   97,
       98,    0,    0,   99,   99,   97,   98,   99,  240,  100,

      240,   99,  100,   99,    0,    0,  100,  101,    0,   99,
      100,  101,  100,    0,    0,  101,  102,  101,  100,  240,
      102,  103,    0,  101,  102,  103,  102,    0,    0,  103,
      104,  103,  102,    0,  104,  105,    0,  103,  104,  105,
      104,    0,    0,  105,    0,  105,  104,    0,  106,  106,
        0,  105,  106,  107,    0,    0,  106,  107,  106,    0,
        0,  107,  108,  107,  106,    0,  108,  109,  109,  107,
      108,  109,  108,    0,    0,  109,    0,  109,  108,    0,
      110,  110,  111,  109,  110,  161,  161,  161,  110,  111,
      110,  161,    0,  111,  112,  161,  110,  111,  112,  111,

        0,    0,  112,  161,  112,  111,    0,  112,  113,  114,
      112,    0,  113,  114,    0,    0,  113,  114,  113,  114,
        0,  114,  115,  116,  113,  114,  115,  116,    0,  115,
      115,  116,  115,  116,    0,    0,  117,  118,  115,  116,
      117,  118,    0,    0,  117,  118,  117,  118,  119,  118,
      119,    0,  117,  118,  119,  120,    0,    0,  119,  120,
      119,  119,    0,  120,  121,  120,  119,    0,  121,    0,
        0,  120,  121,  121,  121,  122,    0,    0,  123,  122,
      121,    0,  123,  122,    0,  122,  123,  122,  123,  124,
        0,  122,  125,  124,  123,    0,    0,  124,  128,  124,

      124,  124,  125,  126,  125,  124,  125,  126,  127,    0,
      125,  126,    0,  126,    0,    0,    0,    0,  127,  126,
      127,  128,  127,    0,    0,  128,  127,    0,  129,  128,
      129,  128,    0,    0,  129,  130,    0,  128,  129,  130,
      129,    0,    0,  130,    0,  130,  129,  131,  131,  132,
        0,  130,  131,  132,    0,    0,  131,  132,  131,  132,
        0,  134,  133,  133,  131,  132,  133,    0,    0,    0,
      133,  134,  133,  134,    0,  134,  135,  135,  133,  134,
        0,  136,    0,    0,  136,    0,    0,  135,    0,  135,
        0,  135,    0,    0,  136,  135,  136,    0,  136,  137,

      138,  162,  136,  162,  137,  138,    0,  162,    0,  137,
      138,  137,  138,  137,  138,  139,  139,  137,  138,  162,
      139,    0,  143,    0,    0,  139,  143,  139,    0,  139,
      143,  144,  143,  139,    0,  144,  145,    0,  143,  144,
      145,  144,    0,    0,  145,    0,  145,  144,    0,  146,
      146,    0,  145,  146,    0,    0,  147,  146,  147,  146,
      148,    0,  147,  147,  148,  146,    0,  147,  148,    0,
      148,  147,    0,  147,  147,    0,  148,  149,  149,  147,
      153,  149,  153,    0,    0,  149,  153,  149,  154,    0,
      154,  153,    0,  149,  154,  156,  154,  156,  153,  156,

        0,  156,    0,    0,    0,  153,  154,    0,  157,    0,
      157,    0,  157,  156,  157,  158,  159,  158,  159,  158,
        0,  158,  159,    0,  159,  160,  157,  160,    0,  158,
      163,  160,  163,  158,  159,    0,  163,  160,  164,    0,
      164,    0,    0,  160,  164,  165,    0,  165,  163,    0,
        0,  165,  166,  167,  166,  167,  164,    0,  166,  167,
      164,    0,  165,  165,    0,    0,    0,    0,    0,    0,
      166,  167,  167,  168,  169,  168,  169,  168,    0,  168,
      169,  170,  169,  170,  171,    0,  171,  170,    0,    0,
      171,  168,  169,  170,  177,  178,  177,  178,    0,  170,

      177,  178,  171,  179,  180,  179,  180,    0,    0,  179,
      180,    0,  177,  178,  181,    0,  181,  182,    0,  182,
      181,  179,  180,  182,  183,  184,  183,  184,    0,    0,
      183,  184,  181,    0,  185,  182,  185,    0,    0,  186,
      185,  186,  183,  184,  184,  186,    0,  187,    0,  187,
        0,    0,  185,  187,  188,    0,  188,  186,  188,    0,
      188,  189,  190,  189,  190,  187,    0,  189,  190,  191,
        0,  191,  188,    0,    0,  191,  192,    0,  192,  189,
      190,    0,  192,  193,  194,  193,  194,  191,    0,  193,
      194,  195,    0,  195,  192,  192,    0,  195,  196,    0,

      196,  193,  194,    0,  196,  197,  198,  197,  198,  195,
        0,  197,  198,  199,    0,  199,  196,    0,    0,  199,
      200,    0,  200,  197,  198,    0,  200,  201,  202,  201,
      202,  199,    0,  201,  202,  203,    0,  203,  200,    0,
        0,  203,  204,    0,  204,  201,  202,    0,  204,  205,
      206,  205,  206,  203,    0,  205,  206,  207,    0,  207,
      204,  204,    0,  207,  208,  208,  208,  205,  206,    0,
      208,  209,  210,  209,  210,  207,    0,  209,  210,  211,
        0,  211,  208,    0,    0,  211,  209,    0,    0,  209,
      210,    0,  212,  213,  212,  213,    0,  211,  212,  213,

        0,  214,  215,  214,  215,    0,  212,  214,  215,    0,
      212,  213,  213,    0,    0,    0,  217,    0,  217,  214,
      215,  216,  217,  216,  218,  216,  218,  216,    0,  219,
      218,  219,    0,    0,  217,  219,    0,    0,    0,  216,
      217,    0,  218,    0,  220,    0,  220,  219,    0,  219,
      220,  221,  223,  221,  223,  221,    0,  221,  223,  224,
        0,  224,  220,    0,    0,  224,    0,    0,    0,  221,
      223,  223,  225,    0,  225,    0,  225,  224,  225,  226,
      227,  226,  227,  226,    0,  226,  227,    0,    0,  228,
      225,  228,  228,    0,  229,  228,  229,  226,  227,  230,

      229,  230,  231,    0,  231,  230,    0,  228,  231,    0,
        0,    0,  229,    0,    0,  231,  232,  230,  232,  233,
      231,  233,  232,  230,  234,  233,  234,  247,  232,  247,
      234,    0,    0,  247,  232,    0,  233,  233,  248,    0,
      248,    0,  234,  234,  248,  247,  249,  250,  249,  250,
        0,    0,  249,  250,    0,  251,  248,  251,    0,    0,
      252,  251,  252,    0,  249,  250,  252,    0,  253,    0,
      253,  253,    0,  251,  253,  254,    0,  254,  252,    0,
        0,  254,  255,    0,  255,  256,  253,  256,  255,  254,
      255,  256,  257,  254,  257,  258,    0,  258,  257,    0,

      255,  258,    0,  256,  256,  259,  260,  259,  260,    0,
      257,  259,  260,  258,  261,  262,  261,  262,    0,    0,
      261,  262,    0,  259,  260,  263,    0,  263,    0,  261,
        0,  263,  261,  262,  264,    0,  264,  262,  264,  265,
      264,  265,  266,  263,  266,  265,    0,  267,  266,  267,
        0,    0,  264,  267,    0,    0,  268,  265,  268,    0,
      266,  269,  268,  269,    0,  267,  270,  269,  270,  271,
        0,  271,  270,    0,  268,  271,  269,    0,    0,  269,
      273,  270,  273,    0,  270,    0,  273,  271,  271,  272,
      272,  272,    0,    0,  275,  272,  275,  274,  273,  274,

      275,  274,  276,  274,  276,    0,    0,  272,  276,    0,
        0,  277,  275,  277,    0,  274,  279,  277,  279,  278,
      276,  278,  279,  278,  280,  278,  280,    0,    0,  277,
      280,    0,    0,  281,  279,  281,    0,  278,  282,  281,
      282,  283,  280,  283,  282,    0,  284,  283,  284,    0,
      281,  281,  284,    0,    0,    0,  282,  282,    0,  283,
      285,  286,  285,  286,  284,  284,  285,  286,    0,  287,
      285,  287,    0,    0,  288,  287,  288,  287,  285,  286,
      288,    0,  289,    0,  289,    0,    0,  287,  289,  290,
        0,  290,  288,    0,    0,  290,  291,  292,  291,  292,

      289,  289,  291,  292,  293,    0,  293,  290,    0,    0,
      293,  294,    0,  294,  291,  292,    0,  294,  295,  296,
      295,  296,  293,    0,  295,  296,  297,    0,  297,  294,
        0,    0,  297,  298,    0,  298,  295,  296,    0,  298,
      299,  300,  299,  300,  297,    0,  299,  300,  301,    0,
      301,  298,    0,    0,  301,    0,    0,  299,  299,  300,
      301,  302,    0,  302,    0,    0,  301,  302,  303,  303,
      303,  306,    0,  306,  303,    0,  307,  306,  307,  302,
        0,  308,  307,  308,  302,    0,  303,  308,    0,  306,
      309,  311,  309,  311,  307,    0,  309,  311,  309,  308,

      310,  310,  310,    0,    0,    0,  310,    0,  309,  311,
      311,  312,    0,  312,  313,  312,  313,  312,  310,  314,
      313,  314,  333,    0,  333,  314,    0,    0,  333,  312,
        0,    0,  313,  334,    0,  334,    0,  314,  313,  334,
      333,  335,  336,  335,  336,    0,    0,  335,  336,    0,
      334,  334,  337,    0,  337,  338,    0,  338,  337,  335,
      336,  338,  339,  340,  339,  340,  337,  338,  339,  340,
      337,    0,  341,  338,  341,    0,    0,  342,  341,  342,
      339,  340,  343,  342,  343,    0,    0,  344,  343,  344,
      341,  341,  345,  344,  345,  342,    0,  346,  345,  346,

      343,    0,  347,  346,  347,  344,    0,  349,  347,  349,
      345,  346,  348,  349,  348,  346,  348,  350,  348,  350,
      347,    0,  351,  350,  351,  349,  349,    0,  351,  351,
      348,    0,  352,    0,  352,  350,  352,  353,  352,  353,
      351,  353,  354,  353,  354,  355,    0,  355,  354,    0,
      352,  355,  356,    0,  356,  353,    0,    0,  356,    0,
      354,    0,  357,  355,  357,  356,  357,  358,  357,  358,
      356,    0,  359,  358,  359,  360,    0,  360,  359,  358,
      357,  360,    0,    0,    0,  358,  361,    0,  361,  362,
      359,  362,  361,  360,    0,  362,  363,  361,  363,  364,

        0,  364,  363,    0,  361,  364,  363,  362,    0,  362,
      365,    0,  365,  368,  363,  368,  365,  364,  366,  368,
      366,    0,  371,  368,  366,    0,    0,    0,  365,    0,
        0,  368,  369,  366,  369,  370,  366,  370,  369,    0,
        0,  370,  371,    0,  371,  369,    0,    0,  371,  372,
      369,  372,  373,  370,  373,  372,    0,    0,  373,  374,
      371,  374,  374,    0,    0,  374,  375,  372,  375,  376,
      373,  376,  375,    0,  377,  376,  377,  374,  377,    0,
      377,    0,    0,    0,  375,  375,  376,  376,  378,  379,
      378,  379,  377,    0,  378,  379,  379,  380,  381,  380,

        0,    0,    0,  380,    0,    0,  378,  379,  380,    0,
      382,  383,  382,  383,    0,  380,  382,  383,  381,    0,
      381,  383,    0,    0,  381,  384,    0,  384,  382,  383,
        0,  384,  385,  386,  385,  386,  381,    0,  385,  386,
      387,    0,  387,  384,    0,    0,  387,  388,    0,  388,
      385,  386,    0,  388,    0,  389,    0,  389,  387,    0,
      387,  389,  390,    0,  390,  388,    0,    0,  390,  391,
      392,  391,  392,  389,    0,  391,  392,  393,    0,  393,
      390,  391,    0,  393,  394,    0,  394,  391,  392,    0,
      394,  395,  396,  395,  396,  393,    0,  395,  396,  398,

        0,  398,  394,    0,    0,  398,    0,  402,    0,  395,
      396,    0,  399,    0,  399,    0,  399,  398,  399,  400,
      401,  400,  401,  400,    0,  400,  401,  402,    0,  402,
      399,    0,  401,  402,  403,    0,  403,  400,  401,    0,
      403,  405,    0,  405,  406,  402,  406,  405,  405,  407,
      406,  407,  403,  407,  408,  407,  408,    0,  408,  405,
      408,    0,  406,  409,  410,  409,  410,  407,    0,  409,
      410,  412,  408,  412,  410,    0,    0,  412,  413,    0,
      413,  409,  410,    0,  413,  414,    0,  414,  412,  412,
        0,  414,  416,  419,  416,  419,  413,    0,  416,  419,

      420,    0,  420,  414,    0,    0,  420,  421,    0,  421,
      416,  419,    0,  421,    0,  422,    0,  422,  420,    0,
      421,  422,  424,    0,  424,  421,    0,    0,  424,  428,
        0,  428,  431,  422,  431,  428,    0,  435,  431,  435,
      424,    0,    0,  435,    0,    0,    0,  428,  428,    0,
      431,    0,    0,    0,    0,  435,  444,  444,  444,  444,
      444,  444,  444,  444,  444,  444,  444,  445,    0,  445,
      445,  445,  445,  445,  445,  445,  445,  445,  446,    0,
      446,  446,  446,  446,  446,  446,  446,  446,  446,  447,
      447,  447,  447,  447,  447,  447,  448,    0,  448,  448,

      448,  448,  448,  448,  448,  448,  448,  449,    0,    0,
        0,  449,  449,  449,  449,  449,  450,    0,    0,    0,
        0,    0,    0,  450,  452,  452,  452,  452,  452,  452,
      452,  452,  453,  453,  453,  453,  453,  453,  453,  453,
      453,  455,  455,  455,  455,  455,  455,  455,  455,  456,
      456,    0,  456,  456,  457,  457,    0,  457,  443,  443,
      443,  443,  443,  443,  443,  443,  443,  443,  443,  443,
      443,  443,  443,  443,  443,  443,  443,  443,  443,  443,
      443,  443,  443,  443,  443,  443,  443,  443,  443,  443,
      443,  443,  443,  443,  443,  443,  443,  443,  443,  443,

      443,  443,  443,  443,  443,  443,  443,  443,  443,  443,
      443,  443,  443,  443,  443,  443,  443,  443,  443
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int bx_flex_debug;
int bx_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *bxtext;
#line 1 "lexer.l"
#line 2 "lexer.l"
/////////////////////////////////////////////////////////////////////////
// $Id$
/////////////////////////////////////////////////////////////////////////

#include <stdlib.h>
#include <string.h>

#ifdef WIN32
	#include <io.h>
	#define YY_NO_UNISTD_H
#endif

#include "debug.h"
#if BX_DEBUGGER

#include "parser.h"

int bx_yyinput(char *buf, int max_size);
#undef YY_INPUT
#define YY_INPUT(buf, ret, max_size) (ret = bx_yyinput(buf, max_size))

static char    *lex_input_ptr = NULL;
static unsigned lex_input_size = 0;

#if BX_SUPPORT_X86_64
  #define LONG_MODE_8BL_REG(reg) \
     { bxlval.uval = reg; return(BX_TOKEN_8BL_REG); }
  #define LONG_MODE_16B_REG(reg) \
     { bxlval.uval = reg; return(BX_TOKEN_16B_REG); }
  #define LONG_MODE_32B_REG(reg) \
     { bxlval.uval = reg; return(BX_TOKEN_32B_REG); }
  #define LONG_MODE_64B_REG(reg) \
     { bxlval.uval = reg; return(BX_TOKEN_64B_REG); }
#else
  #define LONG_MODE_8BL_REG(reg) \
     { bxlval.sval = strdup(bxtext); return(BX_TOKEN_GENERIC); }
  #define LONG_MODE_16B_REG(reg) \
     { bxlval.sval = strdup(bxtext); return(BX_TOKEN_GENERIC); }
  #define LONG_MODE_32B_REG(reg) \
     { bxlval.sval = strdup(bxtext); return(BX_TOKEN_GENERIC); }
  #define LONG_MODE_64B_REG(reg) \
     { bxlval.sval = strdup(bxtext); return(BX_TOKEN_GENERIC); }
#endif



#line 1218 "<stdout>"

#define INITIAL 0
#define EXAMINE 1
#define DISASM 2

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int bxlex_destroy (void );

int bxget_debug (void );

void bxset_debug (int debug_flag  );

YY_EXTRA_TYPE bxget_extra (void );

void bxset_extra (YY_EXTRA_TYPE user_defined  );

FILE *bxget_in (void );

void bxset_in  (FILE * in_str  );

FILE *bxget_out (void );

void bxset_out  (FILE * out_str  );

int bxget_leng (void );

char *bxget_text (void );

int bxget_lineno (void );

void bxset_lineno (int line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int bxwrap (void );
#else
extern int bxwrap (void );
#endif
#endif

    static void yyunput (int c,char *buf_ptr  );
    
#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO fwrite( bxtext, bxleng, 1, bxout )
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( bxin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( bxin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, bxin))==0 && ferror(bxin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(bxin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int bxlex (void);

#define YY_DECL int bxlex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after bxtext and bxleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
#line 51 "lexer.l"

#line 1404 "<stdout>"

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! bxin )
			bxin = stdin;

		if ( ! bxout )
			bxout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			bxensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				bx_create_buffer(bxin,YY_BUF_SIZE );
		}

		bx_load_buffer_state( );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of bxtext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 444 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 2459 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 52 "lexer.l"
; // eat up whitespace
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 53 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_SET); }
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 54 "lexer.l"
{ bxlval.bval = 1; return(BX_TOKEN_ON); }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 55 "lexer.l"
{ bxlval.bval = 0; return(BX_TOKEN_OFF); }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 56 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_CRC); }
	YY_BREAK
case 6:
#line 58 "lexer.l"
case 7:
#line 59 "lexer.l"
case 8:
YY_RULE_SETUP
#line 59 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_CONTINUE); }
	YY_BREAK
case 9:
#line 61 "lexer.l"
case 10:
YY_RULE_SETUP
#line 61 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_STEPN); }
	YY_BREAK
case 11:
#line 63 "lexer.l"
case 12:
#line 64 "lexer.l"
case 13:
YY_RULE_SETUP
#line 64 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_STEP_OVER); }
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 65 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_LIST_BREAK); }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 66 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_VBREAKPOINT); }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 67 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_LBREAKPOINT); }
	YY_BREAK
case 17:
#line 69 "lexer.l"
case 18:
#line 70 "lexer.l"
case 19:
YY_RULE_SETUP
#line 70 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_PBREAKPOINT); }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 71 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_INFO); }
	YY_BREAK
case 21:
#line 73 "lexer.l"
case 22:
YY_RULE_SETUP
#line 73 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_CONTROL_REGS); }
	YY_BREAK
case 23:
#line 75 "lexer.l"
case 24:
YY_RULE_SETUP
#line 75 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_DEBUG_REGS); }
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 76 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_SEGMENT_REGS); }
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 77 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_R); }
	YY_BREAK
case 27:
#line 79 "lexer.l"
case 28:
YY_RULE_SETUP
#line 79 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_REGS); }
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 80 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_FPU); }
	YY_BREAK
case 30:
#line 82 "lexer.l"
case 31:
YY_RULE_SETUP
#line 82 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_SSE); }
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 83 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_MMX); }
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 84 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_CPU); }
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 85 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_IDT); }
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 86 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_IVT); }
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 87 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_GDT); }
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 88 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_LDT); }
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 89 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_TSS); }
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 90 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_TAB); }
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 91 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_LINUX); }
	YY_BREAK
case 41:
#line 93 "lexer.l"
case 42:
#line 94 "lexer.l"
case 43:
YY_RULE_SETUP
#line 94 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_DEL_BREAKPOINT); }
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 95 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_ENABLE_BREAKPOINT); }
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 96 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_DISABLE_BREAKPOINT); }
	YY_BREAK
case 46:
#line 98 "lexer.l"
case 47:
#line 99 "lexer.l"
case 48:
YY_RULE_SETUP
#line 99 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_QUIT); }
	YY_BREAK
case 49:
#line 101 "lexer.l"
case 50:
YY_RULE_SETUP
#line 101 "lexer.l"
{ BEGIN(EXAMINE); bxlval.sval = strdup(bxtext); return(BX_TOKEN_EXAMINE); }
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 102 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_RESTORE); }
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 103 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_SETPMEM); }
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 104 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_QUERY); }
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 105 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_PENDING); }
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 106 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_TAKE); }
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 107 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_DMA); }
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 108 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_IRQ); }
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 109 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_PIC); }
	YY_BREAK
case 59:
#line 111 "lexer.l"
case 60:
YY_RULE_SETUP
#line 111 "lexer.l"
{ BEGIN(DISASM); bxlval.sval = strdup(bxtext); return(BX_TOKEN_DISASM); }
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 112 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_HEX); }
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 113 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_INSTRUMENT); }
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 114 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_STOP); }
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 115 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_DOIT); }
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 116 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_TRACE); }
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 117 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_TRACEREG); }
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 118 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_TRACEMEM); }
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 119 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_SWITCH_MODE); }
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 120 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_SIZE); }
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 121 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_PTIME); }
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 122 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_TIMEBP); }
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 123 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_TIMEBP_ABSOLUTE); }
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 124 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_RECORD); }
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 125 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_PLAYBACK); }
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 126 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_MODEBP); }
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 127 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_PRINT_STACK); }
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 128 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_WATCH); }
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 129 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_UNWATCH); }
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 130 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_READ); }
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 131 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_WRITE); }
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 132 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_SHOW); }
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 133 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_LOAD_SYMBOLS); }
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 134 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_SYMBOLS); }
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 135 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_LIST_SYMBOLS); }
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 136 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_GLOBAL); }
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 137 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_WHERE); }
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 138 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_PRINT_STRING); }
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 139 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_NE2000); }
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 140 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_PAGE); }
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 141 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_VGA); }
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 142 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_PCI); }
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 143 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_ALL); }
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 144 "lexer.l"
{ bxlval.uval = BX_DBG_REG8L_AL; return(BX_TOKEN_8BL_REG);}
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 145 "lexer.l"
{ bxlval.uval = BX_DBG_REG8L_BL; return(BX_TOKEN_8BL_REG);}
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 146 "lexer.l"
{ bxlval.uval = BX_DBG_REG8L_CL; return(BX_TOKEN_8BL_REG);}
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 147 "lexer.l"
{ bxlval.uval = BX_DBG_REG8L_DL; return(BX_TOKEN_8BL_REG);}
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 148 "lexer.l"
{ LONG_MODE_8BL_REG(BX_DBG_REG8L_SIL); }
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 149 "lexer.l"
{ LONG_MODE_8BL_REG(BX_DBG_REG8L_DIL); }
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 150 "lexer.l"
{ LONG_MODE_8BL_REG(BX_DBG_REG8L_SPL); }
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 151 "lexer.l"
{ LONG_MODE_8BL_REG(BX_DBG_REG8L_BPL); }
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 152 "lexer.l"
{ LONG_MODE_8BL_REG(BX_DBG_REG8L_R8);  }
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 153 "lexer.l"
{ LONG_MODE_8BL_REG(BX_DBG_REG8L_R9);  }
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 154 "lexer.l"
{ LONG_MODE_8BL_REG(BX_DBG_REG8L_R10); }
	YY_BREAK
case 104:
YY_RULE_SETUP
#line 155 "lexer.l"
{ LONG_MODE_8BL_REG(BX_DBG_REG8L_R11); }
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 156 "lexer.l"
{ LONG_MODE_8BL_REG(BX_DBG_REG8L_R12); }
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 157 "lexer.l"
{ LONG_MODE_8BL_REG(BX_DBG_REG8L_R13); }
	YY_BREAK
case 107:
YY_RULE_SETUP
#line 158 "lexer.l"
{ LONG_MODE_8BL_REG(BX_DBG_REG8L_R14); }
	YY_BREAK
case 108:
YY_RULE_SETUP
#line 159 "lexer.l"
{ LONG_MODE_8BL_REG(BX_DBG_REG8L_R15); }
	YY_BREAK
case 109:
YY_RULE_SETUP
#line 160 "lexer.l"
{ bxlval.uval = BX_DBG_REG8H_AH; return(BX_TOKEN_8BH_REG);}
	YY_BREAK
case 110:
YY_RULE_SETUP
#line 161 "lexer.l"
{ bxlval.uval = BX_DBG_REG8H_BH; return(BX_TOKEN_8BH_REG);}
	YY_BREAK
case 111:
YY_RULE_SETUP
#line 162 "lexer.l"
{ bxlval.uval = BX_DBG_REG8H_CH; return(BX_TOKEN_8BH_REG);}
	YY_BREAK
case 112:
YY_RULE_SETUP
#line 163 "lexer.l"
{ bxlval.uval = BX_DBG_REG8H_DH; return(BX_TOKEN_8BH_REG);}
	YY_BREAK
case 113:
YY_RULE_SETUP
#line 164 "lexer.l"
{ bxlval.uval = BX_DBG_REG16_AX; return(BX_TOKEN_16B_REG);}
	YY_BREAK
case 114:
YY_RULE_SETUP
#line 165 "lexer.l"
{ bxlval.uval = BX_DBG_REG16_BX; return(BX_TOKEN_16B_REG);}
	YY_BREAK
case 115:
YY_RULE_SETUP
#line 166 "lexer.l"
{ bxlval.uval = BX_DBG_REG16_CX; return(BX_TOKEN_16B_REG);}
	YY_BREAK
case 116:
YY_RULE_SETUP
#line 167 "lexer.l"
{ bxlval.uval = BX_DBG_REG16_DX; return(BX_TOKEN_16B_REG);}
	YY_BREAK
case 117:
YY_RULE_SETUP
#line 168 "lexer.l"
{ bxlval.uval = BX_DBG_REG16_SI; return(BX_TOKEN_16B_REG);}
	YY_BREAK
case 118:
YY_RULE_SETUP
#line 169 "lexer.l"
{ bxlval.uval = BX_DBG_REG16_DI; return(BX_TOKEN_16B_REG);}
	YY_BREAK
case 119:
YY_RULE_SETUP
#line 170 "lexer.l"
{ bxlval.uval = BX_DBG_REG16_BP; return(BX_TOKEN_16B_REG);}
	YY_BREAK
case 120:
YY_RULE_SETUP
#line 171 "lexer.l"
{ bxlval.uval = BX_DBG_REG16_SP; return(BX_TOKEN_16B_REG);}
	YY_BREAK
case 121:
YY_RULE_SETUP
#line 172 "lexer.l"
{ LONG_MODE_16B_REG(BX_DBG_REG16_R8);  }
	YY_BREAK
case 122:
YY_RULE_SETUP
#line 173 "lexer.l"
{ LONG_MODE_16B_REG(BX_DBG_REG16_R9);  }
	YY_BREAK
case 123:
YY_RULE_SETUP
#line 174 "lexer.l"
{ LONG_MODE_16B_REG(BX_DBG_REG16_R10); }
	YY_BREAK
case 124:
YY_RULE_SETUP
#line 175 "lexer.l"
{ LONG_MODE_16B_REG(BX_DBG_REG16_R11); }
	YY_BREAK
case 125:
YY_RULE_SETUP
#line 176 "lexer.l"
{ LONG_MODE_16B_REG(BX_DBG_REG16_R12); }
	YY_BREAK
case 126:
YY_RULE_SETUP
#line 177 "lexer.l"
{ LONG_MODE_16B_REG(BX_DBG_REG16_R13); }
	YY_BREAK
case 127:
YY_RULE_SETUP
#line 178 "lexer.l"
{ LONG_MODE_16B_REG(BX_DBG_REG16_R14); }
	YY_BREAK
case 128:
YY_RULE_SETUP
#line 179 "lexer.l"
{ LONG_MODE_16B_REG(BX_DBG_REG16_R15); }
	YY_BREAK
case 129:
YY_RULE_SETUP
#line 180 "lexer.l"
{ bxlval.uval = BX_DBG_REG32_EAX; return(BX_TOKEN_32B_REG);}
	YY_BREAK
case 130:
YY_RULE_SETUP
#line 181 "lexer.l"
{ bxlval.uval = BX_DBG_REG32_EBX; return(BX_TOKEN_32B_REG);}
	YY_BREAK
case 131:
YY_RULE_SETUP
#line 182 "lexer.l"
{ bxlval.uval = BX_DBG_REG32_ECX; return(BX_TOKEN_32B_REG);}
	YY_BREAK
case 132:
YY_RULE_SETUP
#line 183 "lexer.l"
{ bxlval.uval = BX_DBG_REG32_EDX; return(BX_TOKEN_32B_REG);}
	YY_BREAK
case 133:
YY_RULE_SETUP
#line 184 "lexer.l"
{ bxlval.uval = BX_DBG_REG32_ESI; return(BX_TOKEN_32B_REG);}
	YY_BREAK
case 134:
YY_RULE_SETUP
#line 185 "lexer.l"
{ bxlval.uval = BX_DBG_REG32_EDI; return(BX_TOKEN_32B_REG);}
	YY_BREAK
case 135:
YY_RULE_SETUP
#line 186 "lexer.l"
{ bxlval.uval = BX_DBG_REG32_EBP; return(BX_TOKEN_32B_REG);}
	YY_BREAK
case 136:
YY_RULE_SETUP
#line 187 "lexer.l"
{ bxlval.uval = BX_DBG_REG32_ESP; return(BX_TOKEN_32B_REG);}
	YY_BREAK
case 137:
YY_RULE_SETUP
#line 188 "lexer.l"
{ LONG_MODE_32B_REG(BX_DBG_REG32_R8);  }
	YY_BREAK
case 138:
YY_RULE_SETUP
#line 189 "lexer.l"
{ LONG_MODE_32B_REG(BX_DBG_REG32_R9);  }
	YY_BREAK
case 139:
YY_RULE_SETUP
#line 190 "lexer.l"
{ LONG_MODE_32B_REG(BX_DBG_REG32_R10); }
	YY_BREAK
case 140:
YY_RULE_SETUP
#line 191 "lexer.l"
{ LONG_MODE_32B_REG(BX_DBG_REG32_R11); }
	YY_BREAK
case 141:
YY_RULE_SETUP
#line 192 "lexer.l"
{ LONG_MODE_32B_REG(BX_DBG_REG32_R12); }
	YY_BREAK
case 142:
YY_RULE_SETUP
#line 193 "lexer.l"
{ LONG_MODE_32B_REG(BX_DBG_REG32_R13); }
	YY_BREAK
case 143:
YY_RULE_SETUP
#line 194 "lexer.l"
{ LONG_MODE_32B_REG(BX_DBG_REG32_R14); }
	YY_BREAK
case 144:
YY_RULE_SETUP
#line 195 "lexer.l"
{ LONG_MODE_32B_REG(BX_DBG_REG32_R15); }
	YY_BREAK
case 145:
YY_RULE_SETUP
#line 196 "lexer.l"
{ LONG_MODE_64B_REG(BX_DBG_REG64_RAX); }
	YY_BREAK
case 146:
YY_RULE_SETUP
#line 197 "lexer.l"
{ LONG_MODE_64B_REG(BX_DBG_REG64_RBX); }
	YY_BREAK
case 147:
YY_RULE_SETUP
#line 198 "lexer.l"
{ LONG_MODE_64B_REG(BX_DBG_REG64_RCX); }
	YY_BREAK
case 148:
YY_RULE_SETUP
#line 199 "lexer.l"
{ LONG_MODE_64B_REG(BX_DBG_REG64_RDX); }
	YY_BREAK
case 149:
YY_RULE_SETUP
#line 200 "lexer.l"
{ LONG_MODE_64B_REG(BX_DBG_REG64_RSI); }
	YY_BREAK
case 150:
YY_RULE_SETUP
#line 201 "lexer.l"
{ LONG_MODE_64B_REG(BX_DBG_REG64_RDI); }
	YY_BREAK
case 151:
YY_RULE_SETUP
#line 202 "lexer.l"
{ LONG_MODE_64B_REG(BX_DBG_REG64_RSP); }
	YY_BREAK
case 152:
YY_RULE_SETUP
#line 203 "lexer.l"
{ LONG_MODE_64B_REG(BX_DBG_REG64_RBP); }
	YY_BREAK
case 153:
YY_RULE_SETUP
#line 204 "lexer.l"
{ LONG_MODE_64B_REG(BX_DBG_REG64_R8);  }
	YY_BREAK
case 154:
YY_RULE_SETUP
#line 205 "lexer.l"
{ LONG_MODE_64B_REG(BX_DBG_REG64_R9);  }
	YY_BREAK
case 155:
YY_RULE_SETUP
#line 206 "lexer.l"
{ LONG_MODE_64B_REG(BX_DBG_REG64_R10); }
	YY_BREAK
case 156:
YY_RULE_SETUP
#line 207 "lexer.l"
{ LONG_MODE_64B_REG(BX_DBG_REG64_R11); }
	YY_BREAK
case 157:
YY_RULE_SETUP
#line 208 "lexer.l"
{ LONG_MODE_64B_REG(BX_DBG_REG64_R12); }
	YY_BREAK
case 158:
YY_RULE_SETUP
#line 209 "lexer.l"
{ LONG_MODE_64B_REG(BX_DBG_REG64_R13); }
	YY_BREAK
case 159:
YY_RULE_SETUP
#line 210 "lexer.l"
{ LONG_MODE_64B_REG(BX_DBG_REG64_R14); }
	YY_BREAK
case 160:
YY_RULE_SETUP
#line 211 "lexer.l"
{ LONG_MODE_64B_REG(BX_DBG_REG64_R15); }
	YY_BREAK
case 161:
YY_RULE_SETUP
#line 212 "lexer.l"
{ return(BX_TOKEN_REG_IP); }
	YY_BREAK
case 162:
YY_RULE_SETUP
#line 213 "lexer.l"
{ return(BX_TOKEN_REG_EIP);}
	YY_BREAK
case 163:
YY_RULE_SETUP
#line 214 "lexer.l"
{ return(BX_TOKEN_REG_RIP);}
	YY_BREAK
case 164:
YY_RULE_SETUP
#line 215 "lexer.l"
{ bxlval.uval = BX_DBG_SREG_CS; return(BX_TOKEN_CS); }
	YY_BREAK
case 165:
YY_RULE_SETUP
#line 216 "lexer.l"
{ bxlval.uval = BX_DBG_SREG_ES; return(BX_TOKEN_ES); }
	YY_BREAK
case 166:
YY_RULE_SETUP
#line 217 "lexer.l"
{ bxlval.uval = BX_DBG_SREG_SS; return(BX_TOKEN_SS); }
	YY_BREAK
case 167:
YY_RULE_SETUP
#line 218 "lexer.l"
{ bxlval.uval = BX_DBG_SREG_DS; return(BX_TOKEN_DS); }
	YY_BREAK
case 168:
YY_RULE_SETUP
#line 219 "lexer.l"
{ bxlval.uval = BX_DBG_SREG_FS; return(BX_TOKEN_FS); }
	YY_BREAK
case 169:
YY_RULE_SETUP
#line 220 "lexer.l"
{ bxlval.uval = BX_DBG_SREG_GS; return(BX_TOKEN_GS); }
	YY_BREAK
case 170:
YY_RULE_SETUP
#line 221 "lexer.l"
{ bxlval.uval = 0; return (BX_TOKEN_FLAGS); }
	YY_BREAK
case 171:
YY_RULE_SETUP
#line 222 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_HELP); }
	YY_BREAK
case 172:
#line 224 "lexer.l"
case 173:
YY_RULE_SETUP
#line 224 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_CALC); }
	YY_BREAK
case 174:
YY_RULE_SETUP
#line 225 "lexer.l"
{ BEGIN(INITIAL); bxlval.sval = strdup(bxtext); return(BX_TOKEN_XFORMAT); }
	YY_BREAK
case 175:
YY_RULE_SETUP
#line 226 "lexer.l"
{ BEGIN(INITIAL); bxlval.sval = strdup(bxtext); return(BX_TOKEN_XFORMAT); }
	YY_BREAK
case 176:
YY_RULE_SETUP
#line 227 "lexer.l"
{ BEGIN(INITIAL); bxlval.sval = strdup(bxtext); return(BX_TOKEN_DISFORMAT); }
	YY_BREAK
case 177:
YY_RULE_SETUP
#line 228 "lexer.l"
{ return ('+'); }
	YY_BREAK
case 178:
YY_RULE_SETUP
#line 229 "lexer.l"
{ return ('-'); }
	YY_BREAK
case 179:
YY_RULE_SETUP
#line 230 "lexer.l"
{ return ('*'); }
	YY_BREAK
case 180:
YY_RULE_SETUP
#line 231 "lexer.l"
{ return ('/'); }
	YY_BREAK
case 181:
YY_RULE_SETUP
#line 232 "lexer.l"
{ return (BX_TOKEN_RSHIFT); }
	YY_BREAK
case 182:
YY_RULE_SETUP
#line 233 "lexer.l"
{ return (BX_TOKEN_LSHIFT); }
	YY_BREAK
case 183:
YY_RULE_SETUP
#line 234 "lexer.l"
{ return ('&'); }
	YY_BREAK
case 184:
YY_RULE_SETUP
#line 235 "lexer.l"
{ return ('|'); }
	YY_BREAK
case 185:
YY_RULE_SETUP
#line 236 "lexer.l"
{ return ('^'); }
	YY_BREAK
case 186:
YY_RULE_SETUP
#line 237 "lexer.l"
{ return ('!'); }
	YY_BREAK
case 187:
YY_RULE_SETUP
#line 238 "lexer.l"
{ return ('@'); }
	YY_BREAK
case 188:
YY_RULE_SETUP
#line 239 "lexer.l"
{ return ('('); }
	YY_BREAK
case 189:
YY_RULE_SETUP
#line 240 "lexer.l"
{ return (')'); }
	YY_BREAK
case 190:
#line 242 "lexer.l"
case 191:
YY_RULE_SETUP
#line 242 "lexer.l"
{ bxlval.sval = strdup(bxtext+1); bxlval.sval[strlen(bxlval.sval)-1] = 0; return(BX_TOKEN_STRING); }
	YY_BREAK
case 192:
YY_RULE_SETUP
#line 243 "lexer.l"
{ bxlval.uval = strtoull(bxtext, NULL, 16); return(BX_TOKEN_NUMERIC); }
	YY_BREAK
case 193:
YY_RULE_SETUP
#line 244 "lexer.l"
{ bxlval.uval = strtoull(bxtext, NULL, 8); return(BX_TOKEN_NUMERIC); }
	YY_BREAK
case 194:
YY_RULE_SETUP
#line 245 "lexer.l"
{ bxlval.uval = strtoull(bxtext, NULL, 10); return(BX_TOKEN_NUMERIC); }
	YY_BREAK
case 195:
YY_RULE_SETUP
#line 246 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_COMMAND); }
	YY_BREAK
case 196:
YY_RULE_SETUP
#line 247 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_SYMBOLNAME); }
	YY_BREAK
case 197:
YY_RULE_SETUP
#line 248 "lexer.l"
{ bxlval.sval = strdup(bxtext); return(BX_TOKEN_GENERIC); }
	YY_BREAK
case 198:
YY_RULE_SETUP
#line 249 "lexer.l"
{ return ('\n'); }
	YY_BREAK
case 199:
/* rule 199 can match eol */
YY_RULE_SETUP
#line 250 "lexer.l"
{ return ('\n'); }
	YY_BREAK
case 200:
YY_RULE_SETUP
#line 251 "lexer.l"
; // eat up comments '//'
	YY_BREAK
case 201:
YY_RULE_SETUP
#line 252 "lexer.l"
{ return(bxtext[0]); }
	YY_BREAK
case 202:
YY_RULE_SETUP
#line 253 "lexer.l"
{ BEGIN(INITIAL); unput(*bxtext); }
	YY_BREAK
case 203:
YY_RULE_SETUP
#line 254 "lexer.l"
ECHO;
	YY_BREAK
#line 2446 "<stdout>"
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(EXAMINE):
case YY_STATE_EOF(DISASM):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed bxin at a new source and called
			 * bxlex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = bxin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( bxwrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * bxtext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of bxlex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					bxrealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), (size_t) num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			bxrestart(bxin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) bxrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 444 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    	register char *yy_cp = (yy_c_buf_p);

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 444 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 443);

	return yy_is_jam ? 0 : yy_current_state;
}

    static void yyunput (int c, register char * yy_bp )
{
	register char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up bxtext */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		register int number_to_move = (yy_n_chars) + 2;
		register char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		register char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					bxrestart(bxin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( bxwrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve bxtext */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void bxrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        bxensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            bx_create_buffer(bxin,YY_BUF_SIZE );
	}

	bx_init_buffer(YY_CURRENT_BUFFER,input_file );
	bx_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void bx_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		bxpop_buffer_state();
	 *		bxpush_buffer_state(new_buffer);
     */
	bxensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	bx_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (bxwrap()) processing, but the only time this flag
	 * is looked at is after bxwrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void bx_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	bxin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE bx_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) bxalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in bx_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) bxalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in bx_create_buffer()" );

	b->yy_is_our_buffer = 1;

	bx_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with bx_create_buffer()
 * 
 */
    void bx_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		bxfree((void *) b->yy_ch_buf  );

	bxfree((void *) b  );
}

#ifndef __cplusplus
extern int isatty (int );
#endif /* __cplusplus */
    
/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a bxrestart() or at EOF.
 */
    static void bx_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	bx_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then bx_init_buffer was _probably_
     * called from bxrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void bx_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		bx_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void bxpush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	bxensure_buffer_stack();

	/* This block is copied from bx_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from bx_switch_to_buffer. */
	bx_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void bxpop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	bx_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		bx_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void bxensure_buffer_stack (void)
{
	int num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)bxalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in bxensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)bxrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in bxensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE bx_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) bxalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in bx_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	bx_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to bxlex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       bx_scan_bytes() instead.
 */
YY_BUFFER_STATE bx_scan_string (yyconst char * yystr )
{
    
	return bx_scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to bxlex() will
 * scan from a @e copy of @a bytes.
 * @param bytes the byte buffer to scan
 * @param len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE bx_scan_bytes  (yyconst char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) bxalloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in bx_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = bx_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in bx_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up bxtext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		bxtext[bxleng] = (yy_hold_char); \
		(yy_c_buf_p) = bxtext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		bxleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int bxget_lineno  (void)
{
        
    return bxlineno;
}

/** Get the input stream.
 * 
 */
FILE *bxget_in  (void)
{
        return bxin;
}

/** Get the output stream.
 * 
 */
FILE *bxget_out  (void)
{
        return bxout;
}

/** Get the length of the current token.
 * 
 */
int bxget_leng  (void)
{
        return bxleng;
}

/** Get the current token.
 * 
 */

char *bxget_text  (void)
{
        return bxtext;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void bxset_lineno (int  line_number )
{
    
    bxlineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see bx_switch_to_buffer
 */
void bxset_in (FILE *  in_str )
{
        bxin = in_str ;
}

void bxset_out (FILE *  out_str )
{
        bxout = out_str ;
}

int bxget_debug  (void)
{
        return bx_flex_debug;
}

void bxset_debug (int  bdebug )
{
        bx_flex_debug = bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from bxlex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    bxin = stdin;
    bxout = stdout;
#else
    bxin = (FILE *) 0;
    bxout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * bxlex_init()
     */
    return 0;
}

/* bxlex_destroy is for both reentrant and non-reentrant scanners. */
int bxlex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		bx_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		bxpop_buffer_state();
	}

	/* Destroy the stack itself. */
	bxfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * bxlex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *bxalloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *bxrealloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void bxfree (void * ptr )
{
	free( (char *) ptr );	/* see bxrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 254 "lexer.l"



  int
bx_yyinput(char *buf, int max_size)
{
  int len;

  if (lex_input_size == 0) {
    fprintf(stderr, "lex: no characters in string input buffer.\n");
    exit(1);
  }

  len = strlen(lex_input_ptr) + 1;
  if (len > max_size)
    len = max_size;

  memcpy(buf, lex_input_ptr, len);

  return(len);
}

  void
bx_add_lex_input(char *buf)
{
  lex_input_ptr  = buf;
  lex_input_size = strlen(buf);

  // Since we're parsing from strings, flush out
  // all current buffer state, so the next read
  // requests from yyinput

  bx_flush_buffer( YY_CURRENT_BUFFER );
}

#endif /* if BX_DEBUGGER */

